/* The purpose of this function is to return the index of the sidebar accordion which should be opened by default.
   This function uses param "key" (see header.dox) to determine which accordion is currently being processed. */
function autoExpand(key)
{
    /* This is simply defaulting to opening the API accordion if it's an API page */
    if (isAPIRef())
    {
        if (key == "top_level")
            return 3;
        else 
            return false;
    }
    
    /* Otherwise, it finds the special tag in each file and opens the accordion that way. */
    var autoExpands = $( "#autoExpand" ).find("span");
    
    for (var i = 0; i < autoExpands.length; i++)
    {
        var pos = autoExpands[i].innerText.search(":");
        
        if (pos == -1) 
            continue; // something unexpected. ignore.
        
        var accordion = autoExpands[i].innerText.substring(0, pos);
        var expandedSection = autoExpands[i].innerText.substring(pos + 1, autoExpands[i].innerText.length);

        if (key == accordion)
            return parseInt(expandedSection, 10);
    }
    
    return false;
}


function isAPIRef()
{
    // we test against "functions" later, but there's a page with that word in it, so we bail if that's the case
    if (location.href.includes("using_progress_functions"))
        return false;
    
    var api_ref = [ "_a3_d", "_a3d_", "classes.html", "annotated", "deprecated", "files.html", "functions", "globals", "modules", "struct", "a00", "a01", "a02" ];
    
    for (var i = 0; i < api_ref.length; i++)
    {
        if (location.href.includes(api_ref[i]))
            return true;
    }
    
    return false;
}


// Not all possible URLs have an entry in the sidebar. For these, we need to
// come up with a substitute. For example, the class pages 
// don't have individual menu entries. So this function provides a substitute
// so the code can highlight an appropriate entry in the sidebar and the breadcrumbs 
// will work.
function findSubstituteLeafAnchor()
{
    // this array means any URL which contains an orphans.url value will be correlated with the url in orphans.home
    var orphans = [ { url: "_reader.html", home: "build/overview.html" },
                    { url: "_writer.html", home: "build/overview.html" },
                    { url: "fixed_bugs.html", home: "build/release_notes.html" }
    ];
    
    for (var i = 0; i < orphans.length; i++)
    {
        if (location.href.includes(orphans[i].url))
        {
            var anchors = $( "#accordion_panel" ).find("a");
            
            for (var j = 0; j < anchors.length; j++)
            {
                pos = anchors[j].href.search("build");
                
                if (pos == -1) continue; // something unexpected. ignore.
                
                currentUrl = anchors[j].href.substring(pos);
                
                if (currentUrl.includes(orphans[i].home))
                {
                    return anchors[j];
                }
            }
        }
    }
    
    // this should never happen, but returning empty so we don't ever run into a null issue
    return "";
}


// on some pages, breadcrumbs are not appropriate. test before generating.
function shouldGenerateBreadcrumbs()
{
    if (location.href.includes("main-landing") || 
        location.href.includes("samples.html") || 
        location.href.includes("fixed_bugs.html") || 
        isAPIRef() || 
        location.href.includes("release_notes"))
        return false;
    
    return true;
}
